@@ -20,7 +20,7 @@
 // Own
 #include "TerminalTest.h"
 
-#include "qtest_kde.h"
+#include "qtest.h"
 
 // Konsole
 #include "../TerminalDisplay.h"
@@ -96,18 +96,10 @@ void TerminalTest::testSize()
     // TODO: setSize doesn't change size...
     //display->setSize(80, 25);
 
-    display->setFixedSize(-1, -1);
-    QCOMPARE(display->columns(), 1);
-    QCOMPARE(display->lines(), 1);
-
-    display->setFixedSize(80, 25);
-    QCOMPARE(display->columns(), 80);
-    QCOMPARE(display->lines(), 25);
-
     delete display;
 }
 
-QTEST_KDEMAIN(TerminalTest , GUI)
+QTEST_MAIN(TerminalTest )
 
 #include "TerminalTest.moc"
 
